@@ -10,8 +10,7 @@
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    ******************************************************************************
-    */
+    *******************************************************************************/
 
 #include <stdio.h>
 #include <string.h>
@@ -47,6 +46,7 @@ static int mainloop(void)
 		char inbuf[1024];
 		struct timeval tv;
 		int res;
+		int sockfd = found_getsockfd();
 
 		tv.tv_usec = 0;
 		tv.tv_sec = char_timeout;
@@ -54,7 +54,7 @@ static int mainloop(void)
 		fd_set in_set;
 		FD_ZERO(&in_set);
 		FD_SET(termfd, &in_set);
-		FD_SET(found_getsockfd(), &in_set);
+		FD_SET(sockfd, &in_set);
 
 		if ( (res=select(FD_SETSIZE, &in_set, NULL, NULL, timeout_valid?&tv:NULL)) < 0)
 		{
@@ -80,8 +80,9 @@ static int mainloop(void)
 			tty_process_terminal(inbuf, len);
 		}
 
-		if (found_read() == -1)
-			break;
+		if (FD_ISSET(sockfd, &in_set))
+			if (found_read() == -1)
+				break;
 	}
 	write(termfd, "\n", 1);
 	return 0;
@@ -120,10 +121,7 @@ static void usage(char *prog, FILE * f)
 
 int main(int argc, char *argv[])
 {
-	struct sigaction sa;
-	sigset_t ss;
 	int opt;
-	char *nodename;
 
 	// Deal with command-line arguments.
 	opterr = 0;
@@ -166,7 +164,10 @@ int main(int argc, char *argv[])
 	rahead_change = cterm_rahead_change;
 	if (found_setup_link(argv[optind], DNOBJECT_CTERM, cterm_process_network) == 0)
 	{
-		tty_setup("/dev/fd/0", 1);
+		if (tty_setup("/dev/fd/0", 1) == -1)
+			if (tty_setup("/proc/self/fd/0", 1)) {
+				perror("cannot connect to stdin\n");
+			}
 		mainloop();
 		tty_setup(NULL, 0);
 	}
