@@ -510,13 +510,13 @@ unsigned char dap_message::get_type()
     return msg_type;
 }
 
-char *dap_message::type_name()
+const char *dap_message::type_name()
 {
     return type_name(msg_type);
 }
 
 // Return the message type by name
-char *dap_message::type_name(int msg_type)
+const char *dap_message::type_name(int msg_type)
 {
     static char name[32];
 
@@ -704,6 +704,11 @@ bool dap_attrib_message::read(dap_connection &c)
     return true;
 }
 
+int dap_attrib_message::get_menu_bit(int bit)
+{
+	return attmenu.get_bit(bit);
+}
+
 int dap_attrib_message::get_datatype() {return datatype.get_byte(0); }
 int dap_attrib_message::get_org(){return org.get_int(); }
 int dap_attrib_message::get_rfm(){return rfm.get_int(); }
@@ -725,6 +730,7 @@ int dap_attrib_message::get_hbk(){return hbk.get_int(); }
 int dap_attrib_message::get_ebk(){return ebk.get_int(); }
 int dap_attrib_message::get_ffb(){return ffb.get_short(); }
 int dap_attrib_message::get_sbn(){return sbn.get_int(); }
+int dap_attrib_message::get_jnl(){return jnl.get_byte(0); }
 
 // Returns the filesize in bytes
 unsigned long dap_attrib_message::get_size()
@@ -933,6 +939,8 @@ bool dap_control_message::write(dap_connection &c)
     if (ctlmenu.get_bit(3))  rop.write(c);
     if (ctlmenu.get_bit(4))  hsh.write(c);
     if (ctlmenu.get_bit(5))  display.write(c);
+    if (ctlmenu.get_bit(6))  blkcnt.write(c);
+    if (ctlmenu.get_bit(7))  usz.write(c);
     return c.write();
 }
 
@@ -946,6 +954,8 @@ bool dap_control_message::read(dap_connection &c)
     if (ctlmenu.get_bit(3) &&  !rop.read(c)) return false;
     if (ctlmenu.get_bit(4) &&  !hsh.read(c)) return false;
     if (ctlmenu.get_bit(5) &&  !display.read(c)) return false;
+    if (ctlmenu.get_bit(6) &&  !blkcnt.read(c)) return false;
+    if (ctlmenu.get_bit(7) &&  !usz.read(c)) return false;
     return true;
 }
 void dap_control_message::set_ctlfunc(int f)
@@ -1050,6 +1060,28 @@ void dap_control_message::set_display(int d)
     ctlmenu.set_bit(5);
 }
 
+void dap_control_message::set_blkcnt(int f)
+{
+    blkcnt.set_byte(0,f);
+    ctlmenu.set_bit(6);
+}
+
+int dap_control_message::get_blkcnt()
+{
+    return blkcnt.get_byte(0);
+}
+
+void dap_control_message::set_usz(int f)
+{
+    usz.set_short(f);
+    ctlmenu.set_bit(7);
+}
+
+int dap_control_message::get_usz()
+{
+    return usz.get_short();
+}
+
 //------------------------ dap_contran_message() ------------------------------
 
 bool dap_contran_message::write(dap_connection &c)
@@ -1319,7 +1351,7 @@ int dap_status_message::errno_to_stscode()
     }
 }
 
-char *dap_status_message::get_message()
+const char *dap_status_message::get_message()
 {
 // MACCODEs
     switch (stscode.get_int() >> 12)
@@ -1934,17 +1966,17 @@ char *dap_date_message::get_bdt()
 
 char *dap_date_message::get_udt()
 {
-    return bdt.get_string();
+    return udt.get_string();
 }
 
 time_t dap_date_message::get_cdt_time()
 {
-    return string_to_time_t(edt.get_string());
+    return string_to_time_t(cdt.get_string());
 }
 
 time_t dap_date_message::get_rdt_time()
 {
-    return string_to_time_t(edt.get_string());
+    return string_to_time_t(rdt.get_string());
 }
 
 time_t dap_date_message::get_edt_time()
@@ -1959,7 +1991,7 @@ time_t dap_date_message::get_bdt_time()
 
 time_t dap_date_message::get_udt_time()
 {
-    return string_to_time_t(bdt.get_string());
+    return string_to_time_t(udt.get_string());
 }
 
 int dap_date_message::get_rvn()
@@ -2017,10 +2049,10 @@ time_t dap_date_message::string_to_time_t(const char *d)
     struct tm tm;
     char month[5];
 
-    sscanf(d, "%d-%3s-%d %d:%d:%d",
+    memset(&tm, 0, sizeof(tm));
+    sscanf(d, "%02d-%3s-%02d %02d:%02d:%02d",
 	   &tm.tm_mday, month,      &tm.tm_year,
 	   &tm.tm_hour, &tm.tm_min, &tm.tm_sec);
-
     tm.tm_isdst = -1;
 
     int i = 0;
@@ -2032,6 +2064,14 @@ time_t dap_date_message::string_to_time_t(const char *d)
 	    break;
 	}
     }
+    // Pivot year
+    if (tm.tm_year >= 70)
+            tm.tm_year += 1900;
+    else
+            tm.tm_year += 2000;
+
+    tm.tm_year -= 1900; // for a valid 'struct tm'
+
     return mktime(&tm);
 }
 
@@ -2081,8 +2121,9 @@ char *dap_date_message::make_y2k(char *dt)
     return y2kdate;
 }
 
-char *dap_date_message::months[]={"JAN", "FEB", "MAR", "APR", "MAY", "JUN",
-				  "JUL", "AUG", "SEP", "OCT", "NOV", "DEC"};
+const char *dap_date_message::months[]=
+				{"JAN", "FEB", "MAR", "APR", "MAY", "JUN",
+				 "JUL", "AUG", "SEP", "OCT", "NOV", "DEC"};
 
 //------------------------- dap_alloc_message() ------------------------------
 
@@ -2177,7 +2218,7 @@ mode_t dap_protect_message::get_mode()
     return mode;
 }
 
-char *dap_protect_message::get_protection()
+const char *dap_protect_message::get_protection()
 {
     static char protstring[60];
     int p = 0;
@@ -2217,7 +2258,7 @@ char *dap_protect_message::get_protection()
     return protstring;
 }
 
-char *dap_protect_message::get_owner()
+const char *dap_protect_message::get_owner()
 {
     return owner.get_string();
 }
@@ -2286,7 +2327,7 @@ int dap_protect_message::set_protection(char *prot)
     int i = 0;
     int len = strlen(prot);
 
-    if (prot[i] == '(') 
+    if (prot[i] == '(')
 	    i++;
 
     while (i < len)
