@@ -36,13 +36,20 @@ int rms_close(RMSHANDLE h)
 
     rms_conn *rc = (rms_conn *)h;
     dap_connection *conn = (dap_connection *)rc->conn;
-    
+
+    dap_accomp_message ac;
+    ac.set_cmpfunc(dap_accomp_message::CLOSE);
+    ac.write(*conn);
+
+    dap_message *m;
+    int r = rms_getreply(h, 1, NULL, &m);
+
     conn->close();
     
     delete conn;
     delete rc;
 
-    return 0;
+    return r;
 }
 
 
